@@ -292,7 +292,6 @@ class VacBot():
 
         self.thread_statuses = threading.Thread(target=self.refresh_statuses, daemon=False, name="schedule_thread_statuses")
         self.thread_livemap = threading.Thread(target=self.refresh_liveMap, daemon=False, name="schedule_thread_livemap")
-        self.thread_build_livemap = threading.Thread(target=self.build_liveMap, daemon=False, name="schedule_thread_buildlivemap")
         self.thread_components = threading.Thread(target=self.refresh_components, daemon=False, name="schedule_thread_components")
 
     def connect_and_wait_until_ready(self):
@@ -516,15 +515,12 @@ class VacBot():
             self.exc_command('getCachedMapInfo')
             self.exc_command('getPos',['chargePos','deebotPos'])
             self.exc_command('getMajorMap')
+            self.live_map = self.Map.GetBase64Map()
         except XMPPError as err:
             _LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
             _LOGGER.warning("*** Error type: " + err.etype)
             _LOGGER.warning("*** Error condition: " + err.condition)
 
-    def build_liveMap(self):
-        _LOGGER.debug("BuildLiveMap begin")
-        self.live_map = self.Map.GetBase64Map()
-
     def request_all_statuses(self):
         if not self.thread_statuses.isAlive():
             self.thread_statuses = threading.Thread(target=self.refresh_statuses, daemon=False, name="schedule_thread_statuses")
@@ -534,10 +530,6 @@ class VacBot():
             self.thread_livemap = threading.Thread(target=self.refresh_liveMap, daemon=False, name="schedule_thread_livemap")
             self.thread_livemap.start()
 
-        if not self.thread_build_livemap.isAlive():
-            self.thread_build_livemap = threading.Thread(target=self.build_liveMap, daemon=False, name="schedule_thread_buildlivemap")
-            self.thread_build_livemap.start()
-
         if not self.thread_components.isAlive():
             self.thread_components = threading.Thread(target=self.refresh_components, daemon=False, name="schedule_thread_components")
             self.thread_components.start()
